<template>
  <div>
    <div id="diagnosistab">
      <div id="patient-diagnosis-information">
        <div
          v-show="showConfirm"
          class="success">
          <div class="message">
            <p>Patient {{ newPatient.patient_name }} has been diagnosed with {{ newPatient.diagnosis }}. You may see other patients below by completing the form below.</p>
          </div>
        </div>
        <div v-show="stepOne">
          <h1>Step 1: Enter your patient's information:</h1>
          <form
            id="addPatientForm"
            action="">
            <ul class="errors">
              <li>Please enter a name.</li>
              <li>Please select at least one symptom.</li>
            </ul>
            <div class="clearfix">
              <div class="name">
                <label for="patientName">Patient Name</label>
                <input
                  id="patientName"
                  v-model="newPatient.patient_name"
                  type="text"
                  name="patientName">
              </div>
              <div class="account">
                <label for="copayamount">Copay Amount</label>
                <p>$2.00</p>
              </div>
            </div>
            <p>Select up to four symptoms from below:</p>
            <div
              v-for="n in 4"
              :key="n"
              class="symptom">
              <select
                v-model="symptoms[n-1]"
                :name="'symptom' + n"
                class="slectbox2">
                <option
                  disabled
                  value="0">Please Select...</option>
                <option
                  v-for="symptom in shop.symptoms"
                  :key="symptom.id"
                  :value="symptom.id">{{ symptom.title }}
                </option>
              </select>
            </div>
            <div class="clearfix"/>
            <p>
              <a
                id="step1submit"
                class="button submit"
                @click="getDiseases">Continue to Step 2</a>
            </p>
          </form>
          <h1>Recent Diagnoses</h1>
          <table
            id="recentPatientsTable"
            border="0"
            width="">
            <thead>
              <tr>
                <th>Recent Patients</th>
                <th>Diagnosis</th>
                <th>Time</th>
              </tr>
            </thead>
            <tbody v-show="recentPatients[0]">
              <tr
                v-for="patient in recentPatients"
                :key="patient.id">
                <td>{{ patient.patient_name }}</td>
                <td>
                  <a
                    class="diseaselink"
                    @click.prevent="buildDiseaseModal(patient.diagnosed_with, $refs)">{{ patient.diagnosis }}
                  </a>
                </td>
                <td>{{ moment.utc(patient.created_at).local().format("h:mm A") }}</td>
              </tr>
            </tbody>
          </table>
          <p v-show="!recentPatients[0]">No Recent Diagnoses.</p>
        </div>
        <div
          v-show="stepTwo"
          id="diseases">
          <h1>Step 2: Possible Diseases</h1>
          <div v-if="possibleDiseases !== null">
            <p>Click on disease name to find out more about that disease.</p>
            <table
              border="0"
              width="">
              <thead>
                <tr>
                  <th>Common Name</th>
                  <th>Medical Name</th>
                  <th>&nbsp;</th>
                </tr>
              </thead>
              <tbody>
                <template v-for="disease in possibleDiseases">
                  <tr :key="disease.id">
                    <td>
                      <a
                        class="diseaselink"
                        @click.prevent="buildDiseaseModal(disease, $refs)">{{ disease.common_name }}</a>
                    </td>
                    <td>{{ disease.medical_name }}</td>
                    <td>
                      <a
                        id="step2submit"
                        :diseaseid="disease.common_name"
                        class="diagnosebutton"
                        @click.prevent="selectDiagnosis(disease)">Diagnose</a>
                    </td>
                  </tr>
                </template>
              </tbody>
            </table>
          </div>
          <div
            v-if="possibleDiseases !== null || noMatch === null"
            id="or">
            <p v-if="noMatch === null">There were no diseases matching the selected symptoms.</p>
            <p v-if="noMatch !== null">- or -</p>
            <p>
              <a
                class="button"
                @click="resetSymptoms">Go back and choose different symptoms</a>
            </p>
          </div>
        </div>
      </div>
    </div>
    <shop-modal
      ref="diseaseModal">
      <div
        id="overlay"
        slot="disease">
        <div
          id="diseasewindow"
          class="modalwindow disease popup">
          <h1>{{ selectedDisease.medical_name }}</h1>
          <div class="details">
            <h2>What is it?</h2>
            <p>{{ selectedDisease.description }}</p>
            <h2>Affected Parts of Body</h2>
            <p> {{ selectedDisease.affected_body_parts }}</p>
            <h2>Signs and Symptoms</h2>
            <ul>
              <li
                v-for="(symptom, index) in relatedSymptoms"
                :key="index">{{ symptom.title }}
              </li>
            </ul>
            <h2>Causes</h2>
            <ul>
              <li
                v-for="(cause, index) in selectedDisease.causes"
                :key="index">{{ cause }}
              </li>
            </ul>
            <h2>How to Prevent</h2>
            <ul>
              <li
                v-for="(measure, index) in selectedDisease.preventative_measures"
                :key="index">{{ measure }}
              </li>
            </ul>
            <h2>Treatment</h2>
            <ul>
              <li
                v-for="(treatment, index) in selectedDisease.treatment_options"
                :key="index">{{ treatment }}
              </li>
            </ul>
            <p>&nbsp;</p>
          </div>
          <div class="gradient"/>
          <a
            class="button close"
            @click="$refs.diseaseModal.Close()">Close Window</a>
        </div>
      </div>
    </shop-modal>
  </div>
</template>

<script>
import ShopModal from "../../../../shared/views/ShopModal.vue";
export default {
  components: {
    ShopModal
  },
  props: {
    shop: Object,
    recentPatients: Array
  },
  data() {
    return {
      stepOne: true,
      stepTwo: false,
      noMatch: "",
      showConfirm: false,
      patients: [],
      newPatient: {
        patient_name: "",
        diagnosis: "",
        diagnosed_with: {},
      },
      symptoms: [0,0,0,0],
      possibleDiseases: null,
      selectedDisease: {},
      relatedSymptoms: [],
    };
  },
  methods: {
    getDiseases() {
    this.possibleDiseases = null;
    this.stepOne = false;
    this.stepTwo = true;
    const data = { symptoms: this.symptoms };
    app.session.SetSession()
      .then( () => {
        app.api.Post("/medical/getdiseases/" + app.session.data.id, data)
          .then( Response => {
            console.log(Response);
            if (Response[0]) {
              this.possibleDiseases = Response;
            } else {
              this.noMatch = null;
            }
          })
          .catch( x => app.Message( x.error, "error" ));
      });
    },
    resetSymptoms() {
      // 0 is a placeholder for symptom ID.
      this.symptoms = [0,0,0,0];
      this.stepTwo = false;
      this.stepOne = true;
      this.noMatch = "";
    },
    selectDiagnosis(disease) {
      this.resetSymptoms();
      this.newPatient.diagnosis = disease.common_name;
      this.newPatient.diagnosed_with = disease;
      this.possibleDiseases = [];
      this.showConfirm = true;
      app.session.SetSession()
      .then( () => {
        app.api.Post("/medical/postdiagnosis/" + app.session.data.id, this.newPatient)
          .then( Response => {
            console.log(Response);
            this.$emit("new-patient");
          })
          .catch( x => app.Message( x.error, "error" ));
      });
      setTimeout(() => {
        this.showConfirm = false;
        this.newPatient = {
          patient_name: "",
          diagnosis: "",
          diagnosed_with: {},
        };
        this.selectedDisease ={};
      }, 5000);
    },
    findSymptoms(disease) {
      const data = { disease_id: disease.disease_id };
      this.relatedSymptoms = [];
      app.session.SetSession()
        .then( () => {
          app.api.Post("/medical/findsymptoms/" + app.session.data.id, data)
            .then( Response => {
              console.log(Response);
              this.relatedSymptoms = Response;
            })
            .catch( x => app.Message( x.error, "error" ));
      });
    },
    buildDiseaseModal(disease, ref) {
      ref.diseaseModal.Open();
      this.selectedDisease = disease;
      this.findSymptoms(disease);
    }
  },
};
</script>

<style scoped>
  .details {
    height: 400px;
    overflow-x: scroll;
    margin-bottom: 35px;
  }
</style>
